==> igniteui-react-core-16.16.1.tgz: package/esm5/lib/CancellingMultiScaleImageEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CancellingMultiScaleImageEventArgsDescription } from "./CancellingMultiScaleImageEventArgsDescription";
/**
 * @hidden
 */
var CancellingMultiScaleImageEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CancellingMultiScaleImageEventArgsDescriptionMetadata, _super);
    function CancellingMultiScaleImageEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CancellingMultiScaleImageEventArgsDescriptionMetadata.b = function (a) {
        if (CancellingMultiScaleImageEventArgsDescriptionMetadata.a == null) {
            CancellingMultiScaleImageEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CancellingMultiScaleImageEventArgsDescriptionMetadata.c(CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
        }
        if (a.g(CancellingMultiScaleImageEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.s(CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
    };
    CancellingMultiScaleImageEventArgsDescriptionMetadata.c = function (a) {
        a.item("Uri", "String");
    };
    CancellingMultiScaleImageEventArgsDescriptionMetadata.d = function (a) {
        CancellingMultiScaleImageEventArgsDescriptionMetadata.b(a);
        a.u("CancellingMultiScaleImageEventArgs", function () { return new CancellingMultiScaleImageEventArgsDescription(); });
        a.t("CancellingMultiScaleImageEventArgs", CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
    };
    CancellingMultiScaleImageEventArgsDescriptionMetadata.$t = markType(CancellingMultiScaleImageEventArgsDescriptionMetadata, 'CancellingMultiScaleImageEventArgsDescriptionMetadata');
    CancellingMultiScaleImageEventArgsDescriptionMetadata.a = null;
    return CancellingMultiScaleImageEventArgsDescriptionMetadata;
}(Base));
export { CancellingMultiScaleImageEventArgsDescriptionMetadata };

==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/CancellingMultiScaleImageEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { CancellingMultiScaleImageEventArgsDescription } from "./CancellingMultiScaleImageEventArgsDescription";
/**
 * @hidden
 */
var CancellingMultiScaleImageEventArgsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(CancellingMultiScaleImageEventArgsDescriptionMetadata, _super);
    function CancellingMultiScaleImageEventArgsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    CancellingMultiScaleImageEventArgsDescriptionMetadata.b = function (a) {
        if (CancellingMultiScaleImageEventArgsDescriptionMetadata.a == null) {
            CancellingMultiScaleImageEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            CancellingMultiScaleImageEventArgsDescriptionMetadata.c(CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
        }
        if (a.j(CancellingMultiScaleImageEventArgsDescriptionMetadata.a)) {
            return;
        }
        a.y(CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
    };
    CancellingMultiScaleImageEventArgsDescriptionMetadata.c = function (a) {
        a.item("Uri", "String");
    };
    CancellingMultiScaleImageEventArgsDescriptionMetadata.d = function (a) {
        CancellingMultiScaleImageEventArgsDescriptionMetadata.b(a);
        a.aa("CancellingMultiScaleImageEventArgs", function () { return new CancellingMultiScaleImageEventArgsDescription(); });
        a.z("CancellingMultiScaleImageEventArgs", CancellingMultiScaleImageEventArgsDescriptionMetadata.a);
    };
    CancellingMultiScaleImageEventArgsDescriptionMetadata.$t = markType(CancellingMultiScaleImageEventArgsDescriptionMetadata, 'CancellingMultiScaleImageEventArgsDescriptionMetadata');
    CancellingMultiScaleImageEventArgsDescriptionMetadata.a = null;
    return CancellingMultiScaleImageEventArgsDescriptionMetadata;
}(Base));
export { CancellingMultiScaleImageEventArgsDescriptionMetadata };
